Headbands 101: Taylor Swift Taught a Master Class on the Subject - SELF
Description: Taylor Swift just schooled us on wearing sparkly hair accessories.
Keywords: Hair, headbands, Taylor Swift

Close
Best Stretches For Flexibility
Cozy Vegetarian Winter Soups
21-Day Time Makeover
Yoga For Your Abs
Tone Up With 6 Power Moves
FLASH WHAT'S NEW NOW
2014
Dec 29
11:29 AM
Beauty
By Shannon Farrell

# Headbands 101: Taylor Swift Taught a Master Class on the Subject

Blair Waldorf who? The headband has come a long way from its schoolgirl reputation, thanks to the recent efforts of the always-stylish Taylor Swift. When she recently stepped out in NYC wearing a sparkly hair accessory, she demonstrated three must-know rules to follow when pulling off the accessory:

Keep Your Hair’s Movement: Unless you’re fighting with grown-out bangs, refrain from pulling your headband straight back. Instead, keep your hair’s natural movement by placing your style on top of the hair, not under and behind the ears.

Go Easy on Styling: The simplest way to keep the accessory from looking stuffy is to skip elaborate updos and ringlet curls. Keep the hair more natural and use the headband to add structure.

Make It the Focal Point: With a piece of bling like Taylor’s, keep the rest of the beauty look soft. Although she wore fuchsia lipstick, the singer opted for a matte variety to tone-down the vivid hue.

RELATED:

- The Game-Changing Oil for Dry Hair and Split Ends
- Five Travel-Sized Hair Dryers That Stand Up To The Test
- Here’s More Proof That the Wavy Bob Is 2015’s “It” Cut

Image Credit: Getty

KEYWORDS: Hair,headbands,Taylor Swift

SEE MORE
SEE LESS
OLDER NEWER
Jennifer Lawrence Has the Right Spirit
Move Over Kale, There’s a New Leafy Green to Look Out For
What We're Reading

Hide comments Show comments
Loading Comments...

- Facebook
- Twitter
- Pinterest
- Gplus
- Instragram

More On Self
Emma Watson Shows Us How a Super-Nude Pe
FDA Puts the Smackdown on Indoor Tanning
Hilary Duff Is a Powerhouse
How Many Days a Week Should You Exercise
6 High-Fat Foods That Are Good for You